@@ -1,17 +1,21 @@
 """
 PeeringDB API
 """
+
 import logging
 import sys
+from distutils.util import strtobool
 from importlib import import_module
 
 import pkg_resources
 
+from peeringdb.util import get_log_level
+
 __version__ = pkg_resources.require("peeringdb")[0].version
 _log_level = logging.INFO
 
 
-def _config_logs(lvl=None, name=None):
+def _config_logs(level=None, name=None, allow_other_loggers=False):
     """
     Set up or change logging configuration.
 
@@ -19,19 +23,29 @@ def _config_logs(lvl=None, name=None):
     _config_logs(L) => change log level
     """
     # print('_config_log', 'from %s' %name if name else '')
-    FORMAT = "%(message)s"
+    logging_format = "%(message)s"
     # maybe better for log files
     # FORMAT='[%(levelname)s]:%(message)s',
 
-    # Reset handlers
-    for h in list(logging.root.handlers):
-        logging.root.removeHandler(h)
+    if isinstance(level, str):
+        level = get_log_level(level)
 
     global _log_level
-    if lvl:
-        _log_level = lvl
+    if level:
+        _log_level = level
 
-    logging.basicConfig(level=_log_level, format=FORMAT, stream=sys.stdout)
+    if not isinstance(allow_other_loggers, bool):
+        try:
+            allow_other_loggers = strtobool(str(allow_other_loggers))
+        except Exception:
+            allow_other_loggers = False
+
+    if not allow_other_loggers:
+        # Reset handlers
+        for h in list(logging.root.handlers):
+            logging.root.removeHandler(h)
+
+    logging.basicConfig(level=_log_level, format=logging_format, stream=sys.stdout)
     _log = logging.getLogger(__name__)
     _log.setLevel(_log_level)
 
@@ -84,10 +98,10 @@ def initialize_backend(name, **kwargs):
     # Load internal module associated with the ORM module
     supportmod = import_module(modname)
     # Backend is any object returned from load_backend
-    B = supportmod.load_backend(**kwargs)
+    backend = supportmod.load_backend(**kwargs)
 
-    B.Backend.setup()
-    __backend = (B.Backend(), (name, B.__version__))
+    backend.Backend.setup()
+    __backend = (backend.Backend(), (name, backend.__version__))
 
 
 # TODO
