@@ -1,4 +1,7 @@
+import io
 import logging
+import os
+import subprocess
 import sys
 
 import munge
@@ -7,12 +10,12 @@ import peeringdb
 from peeringdb import config as cfg
 from peeringdb import resource, util
 from peeringdb.client import Client
-from peeringdb.output._yaml import dump
+from peeringdb.output._dict import dump_python_dict
 from peeringdb.whois import WhoisFormat
 
 
 def _handler(func):
-    "Decorate a command handler"
+    """Decorate a command handler"""
 
     def _wrapped(*a, **k):
         r = func(*a, **k)
@@ -24,7 +27,7 @@ def _handler(func):
 
 
 def add_subcommands(parser, commands):
-    "Add commands to a parser"
+    """Add commands to a parser"""
     subps = parser.add_subparsers()
     for cmd, cls in commands:
         subp = subps.add_parser(cmd, help=cls.__doc__)
@@ -59,7 +62,7 @@ class CommandGroup:
 
 
 class Get:
-    "Get a resource"
+    """Get a resource"""
 
     @staticmethod
     def add_arguments(parser):
@@ -88,26 +91,21 @@ class Get:
         for poid in poids:
             (tag, pk) = util.split_ref(poid)
             res = resource.get_resource(tag)
-            B = peeringdb.get_backend()
+            backend = peeringdb.get_backend()
             try:
                 obj = client.get(res, pk)
-            except B.object_missing_error(B.get_concrete(res)):
+            except backend.object_missing_error(backend.get_concrete(res)):
                 if remote:
-                    obj = client.fetch(res, pk, depth)[0]
+                    obj = client.fetcher.get(res.tag, pk, depth=depth)
                 else:
                     print(f"Not found: {tag}-{pk}", file=sys.stderr)
                     return 1
-
-            dump(obj, depth, sys.stdout)
-
-
-def _lookup_tag(tag, key, getfunc):
-    if tag == "as":
-        return getfunc(resource.Network, asn=key)
-    elif tag == "ixnets":
-        return getfunc(resource.Network, ix_id__in=key)
-    else:
-        return getfunc(resource.get_resource(tag), id=key)
+            try:
+                codec = munge.get_codec(output_format)()
+                codec.dump(dump_python_dict(obj, depth), sys.stdout)
+            except TypeError as e:
+                print(f"Output format not supported: {output_format}", file=sys.stderr)
+                return 1
 
 
 class Whois:
@@ -126,22 +124,25 @@ class Whois:
     @_handler
     def handle(config, poids, **_):
         client = Client(config)
-
-        def get(res, **kwargs):
-            objs = client.fetch_all(res, depth=2, **kwargs)
-            if not objs:
-                raise peeringdb.sync.NotFoundException
-            return objs
-
         fmt = WhoisFormat()
+
         for poid in poids:
             (tag, key) = util.split_ref(poid)
             try:
-                data = _lookup_tag(tag, key, get)
-            except peeringdb.sync.NotFoundException:
-                print(f"Not found: resource for {tag}={key}", file=sys.stderr)
+                if tag == "as":
+                    objs = client.fetcher._get("net", asn=key, depth=2)
+                elif tag == "ixnets":
+                    objs = client.fetcher._get("net", ix_id__in=key, depth=2)
+                else:
+                    objs = client.fetcher._get(tag, pk=key, depth=2)
+            except Exception as e:
+                print(f"Not found: {tag}={key}: {e}", file=sys.stderr)
                 return 1
-            fmt.display(tag, data[0])
+            if len(objs) == 0:
+                print(f"Not found: {tag}={key}:", file=sys.stderr)
+                return 1
+
+            fmt.display(tag, objs[0])
 
 
 class DumpConfig:
@@ -187,7 +188,7 @@ class PromptConfig:
 
 
 class ListCodecs:
-    "List available codecs"
+    """List available codecs"""
 
     @_handler
     def handle(**_):
@@ -195,12 +196,18 @@ class ListCodecs:
 
 
 class Sync:
-    "Synchronize local tables to PeeringDB"
+    """Synchronize local tables to PeeringDB"""
 
     @staticmethod
     def add_arguments(parser):
         parser.add_argument("-v", "--verbose", action="count", help="Be more verbose")
         parser.add_argument("-q", "--quiet", action="count", help="Be more quiet")
+        parser.add_argument(
+            "--fetch-private",
+            action="store_true",
+            default=False,
+            help="Fetch private data (needs API key set)",
+        )
         parser.add_argument(
             "--dry-run",
             action="store_true",
@@ -232,9 +239,10 @@ class Sync:
 
         loglvl = 1 + (verbose or 0) - (quiet or 0)
         if loglvl > 1:
-            peeringdb._config_logs(logging.DEBUG)
-        if loglvl < 1:
+            config.update({"log": {"level": logging.DEBUG}})
+        elif loglvl < 1:
             peeringdb._config_logs(logging.WARNING)
+            config.update({"log": {"level": logging.WARNING}})
 
         client = Client(config, **kwargs)
         # todo verify table schema
@@ -246,14 +254,88 @@ class Sync:
 
         if since < 0:
             since = None
-        client.update_all(rs, since)
+
+        # if fetch-private and PDB_SYNC_API_KEY isn't set, warn
+        if kwargs["fetch_private"] and not config["sync"].get("api_key"):
+            print()
+            print(
+                "Warning: api key not set, private data will not be fetched. Set it either directly in the config or provide via the PDB_SYNC_API_KEY environment variable.",
+                file=sys.stderr,
+            )
+            print()
+            kwargs["fetch_private"] = False
+
+        client.updater.update_all(rs, since, fetch_private=kwargs["fetch_private"])
 
 
 class DropTables:
-    "Drop all database tables"
+    """Drop all database tables"""
 
     @_handler
     def handle(config, **_):
         Client(config)
-        B = peeringdb.get_backend()
-        B.delete_all()
+        backend = peeringdb.get_backend()
+        backend.delete_all()
+
+
+class Server:
+    """Configure Peeringdb Server"""
+
+    @staticmethod
+    def add_arguments(parser):
+        parser.add_argument(
+            "--setup",
+            action="store_true",
+            default=False,
+            help="Build and setup peeringdb server container",
+        )
+        parser.add_argument(
+            "--start",
+            action="store_true",
+            default=False,
+            help="Start peeringdb server container",
+        )
+        parser.add_argument(
+            "--stop",
+            action="store_true",
+            default=False,
+            help="Stop peeringdb server container",
+        )
+
+    @_handler
+    def handle(config, setup, start, stop, **_):
+        parent_directory = os.path.abspath(os.path.join(os.getcwd()))
+        clone_path = os.path.join(parent_directory, "peeringdb_server")
+
+        if setup:
+            # Clone the GitHub repository
+            # TODO: use latest release? (peeringdb server currently does no publish releases, just tags)
+            # TODO: use git module instead of subprocess?
+            print("Setup-----------")
+            subprocess.run(
+                [
+                    "git",
+                    "clone",
+                    "https://github.com/peeringdb/peeringdb.git",
+                    clone_path,
+                ]
+            )
+
+            # Run setup.sh inside the cloned repository
+            subprocess.run(["./Ctl/local/setup.sh"], cwd=clone_path)
+
+        if start:
+            try:
+                subprocess.run(["./Ctl/local/compose.sh", "up", "-d"], cwd=clone_path)
+            except FileNotFoundError:
+                print(
+                    f"{clone_path} directory not found, make sure that you already run 'peeringdb server --setup'"
+                )
+
+        if stop:
+            try:
+                subprocess.run(["./Ctl/local/compose.sh", "down"], cwd=clone_path)
+            except FileNotFoundError:
+                print(
+                    f"{clone_path} directory not found, make sure that you already run 'peeringdb server --setup'"
+                )
